/****************************************************************************
** Meta object code from reading C++ file 'gpgaction.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../qca-2.3.12/plugins/qca-gnupg/gpgaction.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gpgaction.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_gpgQCAPlugin__GpgAction_t {
    QByteArrayData data[32];
    char stringdata0[419];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_gpgQCAPlugin__GpgAction_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_gpgQCAPlugin__GpgAction_t qt_meta_stringdata_gpgQCAPlugin__GpgAction = {
    {
QT_MOC_LITERAL(0, 0, 23), // "gpgQCAPlugin::GpgAction"
QT_MOC_LITERAL(1, 24, 9), // "readyRead"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 12), // "bytesWritten"
QT_MOC_LITERAL(4, 48, 5), // "bytes"
QT_MOC_LITERAL(5, 54, 8), // "finished"
QT_MOC_LITERAL(6, 63, 14), // "needPassphrase"
QT_MOC_LITERAL(7, 78, 5), // "keyId"
QT_MOC_LITERAL(8, 84, 8), // "needCard"
QT_MOC_LITERAL(9, 93, 23), // "readyReadDiagnosticText"
QT_MOC_LITERAL(10, 117, 4), // "read"
QT_MOC_LITERAL(11, 122, 5), // "write"
QT_MOC_LITERAL(12, 128, 2), // "in"
QT_MOC_LITERAL(13, 131, 8), // "endWrite"
QT_MOC_LITERAL(14, 140, 8), // "cardOkay"
QT_MOC_LITERAL(15, 149, 18), // "readDiagnosticText"
QT_MOC_LITERAL(16, 168, 7), // "t_dtext"
QT_MOC_LITERAL(17, 176, 10), // "proc_error"
QT_MOC_LITERAL(18, 187, 28), // "gpgQCAPlugin::GPGProc::Error"
QT_MOC_LITERAL(19, 216, 1), // "e"
QT_MOC_LITERAL(20, 218, 13), // "proc_finished"
QT_MOC_LITERAL(21, 232, 8), // "exitCode"
QT_MOC_LITERAL(22, 241, 20), // "proc_readyReadStdout"
QT_MOC_LITERAL(23, 262, 20), // "proc_readyReadStderr"
QT_MOC_LITERAL(24, 283, 25), // "proc_readyReadStatusLines"
QT_MOC_LITERAL(25, 309, 22), // "proc_bytesWrittenStdin"
QT_MOC_LITERAL(26, 332, 20), // "proc_bytesWrittenAux"
QT_MOC_LITERAL(27, 353, 24), // "proc_bytesWrittenCommand"
QT_MOC_LITERAL(28, 378, 10), // "proc_debug"
QT_MOC_LITERAL(29, 389, 3), // "str"
QT_MOC_LITERAL(30, 393, 20), // "appendDiagnosticText"
QT_MOC_LITERAL(31, 414, 4) // "line"

    },
    "gpgQCAPlugin::GpgAction\0readyRead\0\0"
    "bytesWritten\0bytes\0finished\0needPassphrase\0"
    "keyId\0needCard\0readyReadDiagnosticText\0"
    "read\0write\0in\0endWrite\0cardOkay\0"
    "readDiagnosticText\0t_dtext\0proc_error\0"
    "gpgQCAPlugin::GPGProc::Error\0e\0"
    "proc_finished\0exitCode\0proc_readyReadStdout\0"
    "proc_readyReadStderr\0proc_readyReadStatusLines\0"
    "proc_bytesWrittenStdin\0proc_bytesWrittenAux\0"
    "proc_bytesWrittenCommand\0proc_debug\0"
    "str\0appendDiagnosticText\0line"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_gpgQCAPlugin__GpgAction[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      22,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  124,    2, 0x06 /* Public */,
       3,    1,  125,    2, 0x06 /* Public */,
       5,    0,  128,    2, 0x06 /* Public */,
       6,    1,  129,    2, 0x06 /* Public */,
       8,    0,  132,    2, 0x06 /* Public */,
       9,    0,  133,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    0,  134,    2, 0x0a /* Public */,
      11,    1,  135,    2, 0x0a /* Public */,
      13,    0,  138,    2, 0x0a /* Public */,
      14,    0,  139,    2, 0x0a /* Public */,
      15,    0,  140,    2, 0x0a /* Public */,
      16,    0,  141,    2, 0x08 /* Private */,
      17,    1,  142,    2, 0x08 /* Private */,
      20,    1,  145,    2, 0x08 /* Private */,
      22,    0,  148,    2, 0x08 /* Private */,
      23,    0,  149,    2, 0x08 /* Private */,
      24,    0,  150,    2, 0x08 /* Private */,
      25,    1,  151,    2, 0x08 /* Private */,
      26,    1,  154,    2, 0x08 /* Private */,
      27,    1,  157,    2, 0x08 /* Private */,
      28,    1,  160,    2, 0x08 /* Private */,
      30,    1,  163,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::QByteArray,
    QMetaType::Void, QMetaType::QByteArray,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QString,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,   29,
    QMetaType::Void, QMetaType::QString,   31,

       0        // eod
};

void gpgQCAPlugin::GpgAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GpgAction *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->readyRead(); break;
        case 1: _t->bytesWritten((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->finished(); break;
        case 3: _t->needPassphrase((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->needCard(); break;
        case 5: _t->readyReadDiagnosticText(); break;
        case 6: { QByteArray _r = _t->read();
            if (_a[0]) *reinterpret_cast< QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->write((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 8: _t->endWrite(); break;
        case 9: _t->cardOkay(); break;
        case 10: { QString _r = _t->readDiagnosticText();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->t_dtext(); break;
        case 12: _t->proc_error((*reinterpret_cast< gpgQCAPlugin::GPGProc::Error(*)>(_a[1]))); break;
        case 13: _t->proc_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->proc_readyReadStdout(); break;
        case 15: _t->proc_readyReadStderr(); break;
        case 16: _t->proc_readyReadStatusLines(); break;
        case 17: _t->proc_bytesWrittenStdin((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->proc_bytesWrittenAux((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->proc_bytesWrittenCommand((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->proc_debug((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 21: _t->appendDiagnosticText((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (GpgAction::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GpgAction::readyRead)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (GpgAction::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GpgAction::bytesWritten)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (GpgAction::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GpgAction::finished)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (GpgAction::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GpgAction::needPassphrase)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (GpgAction::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GpgAction::needCard)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (GpgAction::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GpgAction::readyReadDiagnosticText)) {
                *result = 5;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject gpgQCAPlugin::GpgAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_gpgQCAPlugin__GpgAction.data,
    qt_meta_data_gpgQCAPlugin__GpgAction,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *gpgQCAPlugin::GpgAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *gpgQCAPlugin::GpgAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_gpgQCAPlugin__GpgAction.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int gpgQCAPlugin::GpgAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void gpgQCAPlugin::GpgAction::readyRead()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void gpgQCAPlugin::GpgAction::bytesWritten(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void gpgQCAPlugin::GpgAction::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void gpgQCAPlugin::GpgAction::needPassphrase(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void gpgQCAPlugin::GpgAction::needCard()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void gpgQCAPlugin::GpgAction::readyReadDiagnosticText()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
