/****************************************************************************
** Meta object code from reading C++ file 'qca_securemessage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../qca-2.3.12/include/QtCrypto/qca_securemessage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qca_securemessage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3QCA13SecureMessageE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::SecureMessage::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA13SecureMessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::SecureMessage",
        "readyRead",
        "",
        "bytesWritten",
        "bytes",
        "finished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'readyRead'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bytesWritten'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SecureMessage, qt_meta_tag_ZN3QCA13SecureMessageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::SecureMessage::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA13SecureMessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA13SecureMessageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA13SecureMessageE_t>.metaTypes,
    nullptr
} };

void QCA::SecureMessage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SecureMessage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readyRead(); break;
        case 1: _t->bytesWritten((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->finished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SecureMessage::*)()>(_a, &SecureMessage::readyRead, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecureMessage::*)(int )>(_a, &SecureMessage::bytesWritten, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecureMessage::*)()>(_a, &SecureMessage::finished, 2))
            return;
    }
}

const QMetaObject *QCA::SecureMessage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::SecureMessage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA13SecureMessageE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Algorithm"))
        return static_cast< Algorithm*>(this);
    return QObject::qt_metacast(_clname);
}

int QCA::SecureMessage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QCA::SecureMessage::readyRead()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QCA::SecureMessage::bytesWritten(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QCA::SecureMessage::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN3QCA19SecureMessageSystemE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::SecureMessageSystem::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA19SecureMessageSystemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::SecureMessageSystem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SecureMessageSystem, qt_meta_tag_ZN3QCA19SecureMessageSystemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::SecureMessageSystem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA19SecureMessageSystemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA19SecureMessageSystemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA19SecureMessageSystemE_t>.metaTypes,
    nullptr
} };

void QCA::SecureMessageSystem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SecureMessageSystem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QCA::SecureMessageSystem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::SecureMessageSystem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA19SecureMessageSystemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Algorithm"))
        return static_cast< Algorithm*>(this);
    return QObject::qt_metacast(_clname);
}

int QCA::SecureMessageSystem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3QCA7OpenPGPE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::OpenPGP::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA7OpenPGPE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::OpenPGP"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenPGP, qt_meta_tag_ZN3QCA7OpenPGPE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::OpenPGP::staticMetaObject = { {
    QMetaObject::SuperData::link<SecureMessageSystem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA7OpenPGPE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA7OpenPGPE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA7OpenPGPE_t>.metaTypes,
    nullptr
} };

void QCA::OpenPGP::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenPGP *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QCA::OpenPGP::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::OpenPGP::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA7OpenPGPE_t>.strings))
        return static_cast<void*>(this);
    return SecureMessageSystem::qt_metacast(_clname);
}

int QCA::OpenPGP::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SecureMessageSystem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3QCA3CMSE_t {};
} // unnamed namespace

template <> constexpr inline auto QCA::CMS::qt_create_metaobjectdata<qt_meta_tag_ZN3QCA3CMSE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QCA::CMS"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CMS, qt_meta_tag_ZN3QCA3CMSE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QCA::CMS::staticMetaObject = { {
    QMetaObject::SuperData::link<SecureMessageSystem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA3CMSE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA3CMSE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3QCA3CMSE_t>.metaTypes,
    nullptr
} };

void QCA::CMS::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CMS *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QCA::CMS::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QCA::CMS::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3QCA3CMSE_t>.strings))
        return static_cast<void*>(this);
    return SecureMessageSystem::qt_metacast(_clname);
}

int QCA::CMS::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SecureMessageSystem::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
