/****************************************************************************
** Meta object code from reading C++ file 'gpgproc_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qca-2.3.12/plugins/qca-gnupg/gpgproc/gpgproc_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gpgproc_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t {};
} // unnamed namespace

template <> constexpr inline auto gpgQCAPlugin::QProcessSignalRelay::qt_create_metaobjectdata<qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "gpgQCAPlugin::QProcessSignalRelay",
        "started",
        "",
        "readyReadStandardOutput",
        "readyReadStandardError",
        "bytesWritten",
        "finished",
        "error",
        "QProcess::ProcessError",
        "proc_started",
        "proc_readyReadStandardOutput",
        "proc_readyReadStandardError",
        "proc_bytesWritten",
        "x",
        "proc_finished",
        "proc_error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyReadStandardOutput'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyReadStandardError'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bytesWritten'
        QtMocHelpers::SignalData<void(qint64)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(QProcess::ProcessError)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'proc_started'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proc_readyReadStandardOutput'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proc_readyReadStandardError'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proc_bytesWritten'
        QtMocHelpers::SlotData<void(qint64)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Slot 'proc_finished'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'proc_error'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QProcessSignalRelay, qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject gpgQCAPlugin::QProcessSignalRelay::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t>.metaTypes,
    nullptr
} };

void gpgQCAPlugin::QProcessSignalRelay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QProcessSignalRelay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started(); break;
        case 1: _t->readyReadStandardOutput(); break;
        case 2: _t->readyReadStandardError(); break;
        case 3: _t->bytesWritten((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 4: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->error((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 6: _t->proc_started(); break;
        case 7: _t->proc_readyReadStandardOutput(); break;
        case 8: _t->proc_readyReadStandardError(); break;
        case 9: _t->proc_bytesWritten((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 10: _t->proc_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->proc_error((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QProcessSignalRelay::*)()>(_a, &QProcessSignalRelay::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QProcessSignalRelay::*)()>(_a, &QProcessSignalRelay::readyReadStandardOutput, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QProcessSignalRelay::*)()>(_a, &QProcessSignalRelay::readyReadStandardError, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QProcessSignalRelay::*)(qint64 )>(_a, &QProcessSignalRelay::bytesWritten, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QProcessSignalRelay::*)(int )>(_a, &QProcessSignalRelay::finished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QProcessSignalRelay::*)(QProcess::ProcessError )>(_a, &QProcessSignalRelay::error, 5))
            return;
    }
}

const QMetaObject *gpgQCAPlugin::QProcessSignalRelay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *gpgQCAPlugin::QProcessSignalRelay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin19QProcessSignalRelayE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int gpgQCAPlugin::QProcessSignalRelay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void gpgQCAPlugin::QProcessSignalRelay::started()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void gpgQCAPlugin::QProcessSignalRelay::readyReadStandardOutput()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void gpgQCAPlugin::QProcessSignalRelay::readyReadStandardError()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void gpgQCAPlugin::QProcessSignalRelay::bytesWritten(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void gpgQCAPlugin::QProcessSignalRelay::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void gpgQCAPlugin::QProcessSignalRelay::error(QProcess::ProcessError _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto gpgQCAPlugin::GPGProc::Private::qt_create_metaobjectdata<qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "gpgQCAPlugin::GPGProc::Private",
        "doStart",
        "",
        "aux_written",
        "x",
        "aux_error",
        "QCA::QPipeEnd::Error",
        "command_written",
        "command_error",
        "status_read",
        "status_error",
        "e",
        "proc_started",
        "proc_readyReadStandardOutput",
        "proc_readyReadStandardError",
        "proc_bytesWritten",
        "lx",
        "proc_finished",
        "proc_error",
        "QProcess::ProcessError",
        "doTryDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doStart'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'aux_written'
        QtMocHelpers::SlotData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'aux_error'
        QtMocHelpers::SlotData<void(QCA::QPipeEnd::Error)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'command_written'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'command_error'
        QtMocHelpers::SlotData<void(QCA::QPipeEnd::Error)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'status_read'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'status_error'
        QtMocHelpers::SlotData<void(QCA::QPipeEnd::Error)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 11 },
        }}),
        // Slot 'proc_started'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proc_readyReadStandardOutput'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proc_readyReadStandardError'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'proc_bytesWritten'
        QtMocHelpers::SlotData<void(qint64)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 16 },
        }}),
        // Slot 'proc_finished'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'proc_error'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 4 },
        }}),
        // Slot 'doTryDone'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Private, qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject gpgQCAPlugin::GPGProc::Private::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t>.metaTypes,
    nullptr
} };

void gpgQCAPlugin::GPGProc::Private::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Private *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doStart(); break;
        case 1: _t->aux_written((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->aux_error((*reinterpret_cast<std::add_pointer_t<QCA::QPipeEnd::Error>>(_a[1]))); break;
        case 3: _t->command_written((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->command_error((*reinterpret_cast<std::add_pointer_t<QCA::QPipeEnd::Error>>(_a[1]))); break;
        case 5: _t->status_read(); break;
        case 6: _t->status_error((*reinterpret_cast<std::add_pointer_t<QCA::QPipeEnd::Error>>(_a[1]))); break;
        case 7: _t->proc_started(); break;
        case 8: _t->proc_readyReadStandardOutput(); break;
        case 9: _t->proc_readyReadStandardError(); break;
        case 10: _t->proc_bytesWritten((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 11: _t->proc_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->proc_error((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 13: _t->doTryDone(); break;
        default: ;
        }
    }
}

const QMetaObject *gpgQCAPlugin::GPGProc::Private::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *gpgQCAPlugin::GPGProc::Private::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12gpgQCAPlugin7GPGProc7PrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int gpgQCAPlugin::GPGProc::Private::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
